@@ -29,12 +29,14 @@
 
 #include <gtk/gtk.h>
 
+#include "common.h"
 #include "path.h"
 #include "config.h"
 
 static const gchar * authors[] =
 {
   "Nedko Arnaudov <nedko@arnaudov.name> - http://nedko.arnaudov.name",
+  "Alessio Treglia <alessio@debian.org>",
   NULL
 };
 
@@ -400,12 +402,9 @@ on_about_clicked(
 
   g_signal_connect(about, "response", G_CALLBACK(gtk_widget_destroy), NULL);
 
-  if (window != NULL)
-  {
-    gtk_window_set_transient_for(
-      GTK_WINDOW(about),
-      GTK_WINDOW(window));
-  }
+  gtk_window_set_transient_for(
+    GTK_WINDOW(about),
+    GTK_WINDOW(g_main_window_ptr));
 
   gtk_widget_show(about);
 }
